## File System

- **File System**: btrfs

## Boot Loader

- **Boot Loader**: GNU GRUB (Grand Unified Boot Loader)

## Login Manager & Session Manager

- **Login Manager & Session Manager**: SDDM (Simple Desktop Display Manager)

## Package Management

- **Default**: pacman
- **Others**: wget, Homebrew

## Fonts

- **Fonts**: JetBrains Mono Nerd Fonts

## Audio

- **Audio System**: Pipewire

---

### GUI Setup

- **Window Manager**: hyprland (Tiling)
- **Status Bar**: Waybar
- **Notification Manager**: Dunst
- **Browser**: Firefox
- **Code Editor**: VSCodium
- **Image Viewer**: feh
- **Video Player**: VLC
- **Color Picker**: hyprpicker
- **Wallpaper Utility**: hyprpaper
- **Screenshot Utility**: hyprshot
- **File Manager**: Thunar
- **App Launcher**: Rofi
- **Wi-Fi & Bluetooth Management**: Rofi

---

### CLI Setup

- **Terminal Emulator**: kitty
- **Shell**: Zsh (z-shell)
- **Terminal Prompt**: Starship / Oh My Posh
- **History Manager**: Atuin
- **Search Utility**: Fzf (Fuzzy Finder)
- **Terminal Multiplexer**: tmux
- **Git Management**: gitui, lazygit
- **Code Editors**: Neovim, Nano, Vim
- **Task Manager**: btop
- **Trash Control**: trashy
- **Fetch Utilities**: nitch, fastfetch, cutefetch
- **Zip Management**: unzip
- **Clipboard Management**: cliphist, wl-clipboard
- **File Manager**: yazi

---

### CLI Alternatives

- **cd**: zoxide
- **ls**: eza / exa
- **cat**: bat
- **man**: tldr

---

### System Management

- **Network Management**: NetworkManager (nmcli), iwd (iNet Wireless Daemon)
- **Bluetooth Management**: Bluez, Bluez-utils
- **Audio Management**: pamixer, PulseAudio
- **Brightness Control**: brightnessctl
- **Power Management**: acpi
- **Media Player Control**: playerctl

---

## To-Do List

### System Monitoring & Performance

- [ ] Install `gotop` or `glances` for system monitoring.
- [ ] Set up `cpupower` for CPU management.
- [x] Use `nvidia-settings` or `optimus-manager` for NVIDIA GPU management. ✅ 2024-09-11

### Security & Backup

- [ ] Install `ufw` or `firewalld` for managing firewall.
- [ ] Set up `timeshift` or `restic` for automated backups.

### Window Manager Tools

- [ ] Add `picom` for window effects and transparency.
- [ ] Explore `bismuth` or `skippy-xd` for advanced window management.

### Shell Utilities

- [ ] Install `autojump` as an alternative to `cd`.
- [ ] Add `httpie` for API requests.
- [ ] Use `ripgrep` (`rg`) for faster file searches.
- [ ] Try `htop` as a lightweight alternative to `btop`.

### Productivity Tools

- [ ] Install `rsync` or `rclone` for efficient file transfer.
- [ ] Set up `paru` or `yay` for AUR package management.
- [ ] Use `borg` or `rsnapshot` for file backups.

### Clipboard & File Utilities

- [ ] Add `greenclip` for clipboard history management (GUI).
- [ ] Use `lf` or `nnn` for terminal-based file management with previews.
- [ ] Install `zathura` for minimalistic PDF viewing.

### Developer Tools

- [ ] Install `prettier`, `eslint`, or `shellcheck` for linting and formatting.
- [ ] Set up `podman` or `docker` for containerized environments.
- [ ] Add `cmake` or `meson` for compiling and building software from source.

### Miscellaneous Tools

- [ ] Install `pass` for password management in the terminal.
- [ ] Try `calcurse` for task and calendar management.
- [ ] Set up `nvtop` for GPU monitoring.
- [ ] Use `ncdu` for disk usage visualization.
- [ ] Install `tlp` for laptop power management.
